@@ -62,12 +62,14 @@ __all__ = [
 ]
 
 
-class Filter(object):
+class Filter:
     creation_counter = 0
     field_class = forms.Field
 
-    def __init__(self, field_name=None, lookup_expr='exact', *, label=None,
+    def __init__(self, field_name=None, lookup_expr=None, *, label=None,
                  method=None, distinct=False, exclude=False, **kwargs):
+        if lookup_expr is None:
+            lookup_expr = settings.DEFAULT_LOOKUP_EXPR
         self.field_name = field_name
         self.lookup_expr = lookup_expr
         self.label = label
@@ -81,12 +83,6 @@ class Filter(object):
         self.creation_counter = Filter.creation_counter
         Filter.creation_counter += 1
 
-        # TODO: remove assertion in 2.1
-        assert not isinstance(self.lookup_expr, (type(None), list)), \
-            "The `lookup_expr` argument no longer accepts `None` or a list of " \
-            "expressions. Use the `LookupChoiceFilter` instead. See: " \
-            "https://django-filter.readthedocs.io/en/master/guide/migration.html"
-
     def get_method(self, qs):
         """Return filter method based on whether we're excluding
            or simply filtering.
@@ -254,7 +250,7 @@ class MultipleChoiceFilter(Filter):
 
     def get_filter_predicate(self, v):
         name = self.field_name
-        if name and self.lookup_expr != 'exact':
+        if name and self.lookup_expr != settings.DEFAULT_LOOKUP_EXPR:
             name = LOOKUP_SEP.join([name, self.lookup_expr])
         try:
             return {name: getattr(v, self.field.to_field_name)}
@@ -295,7 +291,7 @@ class DurationFilter(Filter):
     field_class = forms.DurationField
 
 
-class QuerySetRequestMixin(object):
+class QuerySetRequestMixin:
     """
     Add callable functionality to filters that support the ``queryset``
     argument. If the ``queryset`` is callable, then it **must** accept the
@@ -627,7 +623,7 @@ class LookupChoiceFilter(Filter):
             field = get_model_field(self.model, self.field_name)
             lookups = field.get_lookups()
 
-        return [self.normalize_lookup(l) for l in lookups]
+        return [self.normalize_lookup(lookup) for lookup in lookups]
 
     @property
     def field(self):
@@ -646,10 +642,10 @@ class LookupChoiceFilter(Filter):
 
     def filter(self, qs, lookup):
         if not lookup:
-            return super(LookupChoiceFilter, self).filter(qs, None)
+            return super().filter(qs, None)
 
         self.lookup_expr = lookup.lookup_expr
-        return super(LookupChoiceFilter, self).filter(qs, lookup.value)
+        return super().filter(qs, lookup.value)
 
 
 class OrderingFilter(BaseCSVFilter, ChoiceFilter):
@@ -750,7 +746,7 @@ class OrderingFilter(BaseCSVFilter, ChoiceFilter):
         return [val for pair in zip(ascending, descending) for val in pair]
 
 
-class FilterMethod(object):
+class FilterMethod:
     """
     This helper is used to override Filter.filter() when a 'method' argument
     is passed. It proxies the call to the actual method on the filter's parent.
